{% load i18n tz highlight %}
{% block content %}
  <div class="row">
    <div class="col-md-12">
      <h4><a href="{{result.url}}">
        [{% highlight result.category with query %}] {% highlight result.title with query %} <br>
        <small>Criado por {{result.created_by}}</small>
      </a></h4>
      <p>

      </p>
      <small class="colab-result-register">{% trans "Registred in" %}:
          <strong>{{result.type}}</strong>
      </small>
    </div>
    <hr>
  </div>
{% endblock content %}