{% load staticfiles %}

<li class="menu-list__item">
  <a class="menu-list__link" href="{% url 'discourse:colab_discourse' '' %}" title="Opine em temas que te afetam como cidadão">
    <div class="logo logo--menu-list">
      <div class="logo__icon--discourse">
        <img class="logo__image" src="{% static 'img/logo-expressao-image.svg' %}" data-fallback="{% static 'img/logo-expressao-image.png' %}">
      </div>
    </div>
    <span class="menu-list__text">Expressão</span>
  </a>
</li>