{% extends "plugins-base.html" %}
{% load staticfiles %}

{% block styles %}
  {{ block.super }}
  <link rel="stylesheet" href="{% static 'overrides-discourse.scss' %}" type="text/x-scss" />
{% endblock styles %}

{% block jquery_call %}
{% endblock jquery_call %}
